@@ -1,6 +1,6 @@
 package Map::Tube::NYC::Line::IRTFlushing;
 
-$Map::Tube::NYC::Line::IRTFlushing::VERSION   = '0.34';
+$Map::Tube::NYC::Line::IRTFlushing::VERSION   = '0.35';
 $Map::Tube::NYC::Line::IRTFlushing::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -12,7 +12,7 @@ Map::Tube::NYC::Line::IRTFlushing - NYC Subway Map: IRT Flushing Line.
 
 =head1 VERSION
 
-Version 0.34
+Version 0.35
 
 =head1 DESCRIPTION
 
@@ -49,22 +49,24 @@ NYC Subway Map: IRT Flushing Line.
 
 =over 2
 
-=item * The station "Court Square" is also part of L<IND Crosstown Line|Map::Tube::NYC::Line::INDCrosstown>.
+=item * The station "Court Square" is also part of
+          L<IND Crosstown Line|Map::Tube::NYC::Line::INDCrosstown>.
 
-=item * The station "42nd Street" is also part of L<IND Eighth Avenue Line|Map::Tube::NYC::Line::INDEighthAvenue>
+=item * The station "42nd Street" is also part of
+          L<IND Eighth Avenue Line|Map::Tube::NYC::Line::INDEighthAvenue>
         | L<IRT Lexington Avenue Line|Map::Tube::NYC::Line::IRTLexingtonAvenue>.
 
 =back
 
 =head1 MAP
 
-NYC Subway Map: L<IRT Flushing Line|https://raw.githubusercontent.com/Manwar/Map-Tube-NYC/master/maps/IRT-Flushing.png>
+NYC Subway Map: L<IRT Flushing Line|https://raw.githubusercontent.com/manwar/Map-Tube-NYC/master/maps/IRT-Flushing.png>
 map generated by plugin L<Map::Tube::Plugin::Graph>.
 
 =begin html
 
-<a href = "https://raw.githubusercontent.com/Manwar/Map-Tube-NYC/master/maps/IRT-Flushing.png">
-<img src    = "https://raw.githubusercontent.com/Manwar/Map-Tube-NYC/master/maps/IRT-Flushing.png"
+<a href = "https://raw.githubusercontent.com/manwar/Map-Tube-NYC/master/maps/IRT-Flushing.png">
+<img src    = "https://raw.githubusercontent.com/manwar/Map-Tube-NYC/master/maps/IRT-Flushing.png"
      alt    = "NYC Subway Map: IRT Flushing Line"
      width  = "600px"
      height = "500px"/>
